@@ -664,16 +664,26 @@ static int do_setopt (Easy_Type *ez, CURLoption opt, int nargs)
       case CURLOPT_FTP_SSL:
 	return set_long_opt (ez, opt, nargs, 0, 0L);   /* FIXME: specific values */
 
+#ifdef CURLOPT_SOURCE_URL
       case CURLOPT_SOURCE_URL:
+	return set_string_opt (ez, opt, nargs);
+#endif
+#ifdef CURLOPT_SOURCE_USERPWD
       case CURLOPT_SOURCE_USERPWD:
 	return set_string_opt (ez, opt, nargs);
-
+#endif
+#ifdef CURLOPT_SOURCE_QUOTE
       case CURLOPT_SOURCE_QUOTE:
 	return set_strlist_opt (ez, opt, nargs, &ez->source_quote);
+#endif
+#ifdef CURLOPT_SOURCE_PREQUOTE
       case CURLOPT_SOURCE_PREQUOTE:
 	return set_strlist_opt (ez, opt, nargs, &ez->source_prequote);
+#endif
+#ifdef CURLOPT_SOURCE_POSTQUOTE
       case CURLOPT_SOURCE_POSTQUOTE:
 	return set_strlist_opt (ez, opt, nargs, &ez->source_postquote);
+#endif
 
       case CURLOPT_FTP_ACCOUNT:
 	return set_string_opt (ez, opt, nargs);
@@ -1536,11 +1546,21 @@ static SLang_IConstant_Type Module_IConstants [] =
    MAKE_ICONSTANT("CURLOPT_FTP_CREATE_MISSING_DIRS", CURLOPT_FTP_CREATE_MISSING_DIRS),
    MAKE_ICONSTANT("CURLOPT_FTP_RESPONSE_TIMEOUT", CURLOPT_FTP_RESPONSE_TIMEOUT),
    MAKE_ICONSTANT("CURLOPT_FTP_SSL", CURLOPT_FTP_SSL),
+#ifdef CURLOPT_SOURCE_URL
    MAKE_ICONSTANT("CURLOPT_SOURCE_URL", CURLOPT_SOURCE_URL),
+#endif
+#ifdef CURLOPT_SOURCE_USERPWD
    MAKE_ICONSTANT("CURLOPT_SOURCE_USERPWD", CURLOPT_SOURCE_USERPWD),
+#endif
+#ifdef CURLOPT_SOURCE_QUOTE
    MAKE_ICONSTANT("CURLOPT_SOURCE_QUOTE", CURLOPT_SOURCE_QUOTE),
+#endif
+#ifdef CURLOPT_SOURCE_PREQUOTE
    MAKE_ICONSTANT("CURLOPT_SOURCE_PREQUOTE", CURLOPT_SOURCE_PREQUOTE),
+#endif
+#ifdef CURLOPT_SOURCE_POSTQUOTE
    MAKE_ICONSTANT("CURLOPT_SOURCE_POSTQUOTE", CURLOPT_SOURCE_POSTQUOTE),
+#endif
    MAKE_ICONSTANT("CURLOPT_FTP_ACCOUNT", CURLOPT_FTP_ACCOUNT),
    MAKE_ICONSTANT("CURLOPT_TRANSFERTEXT", CURLOPT_TRANSFERTEXT),
    MAKE_ICONSTANT("CURLOPT_CRLF", CURLOPT_CRLF),
